@@ -49,6 +49,8 @@ LIMBAPI_CFLAGS or something is going wrong */
 
 #define d(x) x
 
+G_DEFINE_TYPE (ExchangeMAPIAccountListener, exchange_mapi_account_listener, G_TYPE_OBJECT)
+
 struct _ExchangeMAPIAccountListenerPrivate {
 	GConfClient *gconf_client;
 	/* we get notification about mail account changes from this object */
@@ -68,8 +70,6 @@ struct _ExchangeMAPIAccountInfo {
 /* list of ExchangeMAPIAccountInfo structures */
 static 	GList *mapi_accounts = NULL;
 
-#define PARENT_TYPE G_TYPE_OBJECT
-
 static GObjectClass *parent_class = NULL;
 
 static void 
@@ -113,7 +113,7 @@ exchange_mapi_account_listener_class_init (ExchangeMAPIAccountListenerClass *cla
 {
 	GObjectClass *object_class;
 	
-	parent_class = g_type_class_ref (PARENT_TYPE);
+	parent_class = g_type_class_ref (G_TYPE_OBJECT);
 	object_class = G_OBJECT_CLASS (class);
 	
 	/* virtual method override */
@@ -122,7 +122,7 @@ exchange_mapi_account_listener_class_init (ExchangeMAPIAccountListenerClass *cla
 }
 
 static void 
-exchange_mapi_account_listener_init (ExchangeMAPIAccountListener *config_listener, ExchangeMAPIAccountListenerClass *class)
+exchange_mapi_account_listener_init (ExchangeMAPIAccountListener *config_listener)
 {
 	config_listener->priv = g_new0 (ExchangeMAPIAccountListenerPrivate, 1);
 }
@@ -220,7 +220,11 @@ add_cal_esource (EAccount *account, GSList *folders, ExchangeMAPIFolderType fold
 	gconf_client_set_bool (client, ITIP_MESSAGE_HANDLING, TRUE, NULL);
 	source_list = e_source_list_new_for_gconf (client, conf_key);
 	base_uri = g_strdup_printf ("%s%s@%s/", MAPI_URI_PREFIX, url->user, url->host);
-	group = e_source_group_new (account->name, base_uri);
+	group = e_source_list_peek_group_by_base_uri (source_list, base_uri);
+	if (group)
+		e_source_group_set_name (group, account->name);
+	else
+		group = e_source_group_new (account->name, base_uri);
 	g_free (base_uri);
 	e_source_group_set_property (group, "create_source", "yes");
 	e_source_group_set_property (group, "username", url->user);
@@ -426,7 +430,11 @@ add_addressbook_sources (EAccount *account, GSList *folders)
 	base_uri = g_strdup_printf ("mapi://%s@%s/", url->user, url->host);
 	client = gconf_client_get_default ();
 	list = e_source_list_new_for_gconf (client, "/apps/evolution/addressbook/sources" );
-	group = e_source_group_new (account->name, base_uri);
+	group = e_source_list_peek_group_by_base_uri (list, base_uri);
+	if (group)
+		e_source_group_set_name (group, account->name);
+	else
+		group = e_source_group_new (account->name, base_uri);
 	e_source_group_set_property (group, "user", url->user);
 	e_source_group_set_property (group, "host", url->host);
 	e_source_group_set_property (group, "profile", camel_url_get_param (url, "profile"));
@@ -607,7 +615,7 @@ mapi_account_removed (EAccountList *account_listener, EAccount *account)
 }
 
 static gboolean
-create_profile_entry (CamelURL *url)
+create_profile_entry (CamelURL *url, EAccount *account)
 {
 	gboolean status = FALSE;
 	guint8 attempts = 0; 
@@ -618,7 +626,7 @@ create_profile_entry (CamelURL *url)
 		key = camel_url_to_string (url, CAMEL_URL_HIDE_PASSWORD | CAMEL_URL_HIDE_PARAMS);
 		password = e_passwords_get_password (EXCHANGE_MAPI_PASSWORD_COMPONENT, key);
 		if (!password) {
-			gboolean remember = FALSE;
+			gboolean remember = account && e_account_get_bool (account, E_ACCOUNT_SOURCE_SAVE_PASSWD);
 			gchar *title;
 
 			title = g_strdup_printf (_("Enter Password for %s@%s"), url->user, url->host);
@@ -681,12 +689,12 @@ mapi_account_changed (EAccountList *account_listener, EAccount *account)
 
 	if (existing_account_info == NULL && isa_mapi_account) {
 		/* some account of other type is changed to MAPI */
-		if (create_profile_entry (new_url)) {
+		if (create_profile_entry (new_url, account)) {
 			/* Things are successful */
 			gchar *profname = NULL, *uri = NULL; 
 			ExchangeMAPIAccountListener *config_listener = exchange_mapi_accounts_peek_config_listener();
 
-			profname = g_strdup_printf("%s@%s", new_url->user, camel_url_get_param (new_url, "domain"));
+			profname = exchange_mapi_util_profile_name (new_url->user, camel_url_get_param (new_url, "domain"));
 			camel_url_set_param(new_url, "profile", profname);
 			g_free (profname);
 
@@ -714,12 +722,12 @@ mapi_account_changed (EAccountList *account_listener, EAccount *account)
 		} else if (!mapi_camel_url_equal (old_url, new_url) || (existing_account_info->enabled != account->enabled)) {
 		/* Some or all of the account info changed OR the account has been moved from a disabled state to enabled state */
 			mapi_account_removed (account_listener, account);
-			if (create_profile_entry (new_url)) {
+			if (create_profile_entry (new_url, account)) {
 				/* Things are successful */
 				gchar *profname = NULL, *uri = NULL; 
 				ExchangeMAPIAccountListener *config_listener = exchange_mapi_accounts_peek_config_listener();
 
-				profname = g_strdup_printf("%s@%s", new_url->user, camel_url_get_param (new_url, "domain"));
+				profname = exchange_mapi_util_profile_name (new_url->user, camel_url_get_param (new_url, "domain"));
 				camel_url_set_param(new_url, "profile", profname);
 				g_free (profname);
 
@@ -770,30 +778,8 @@ exchange_mapi_account_listener_construct (ExchangeMAPIAccountListener *config_li
 	g_signal_connect (config_listener->priv->account_list, "account_removed", G_CALLBACK (mapi_account_removed), NULL);
 }
 
-GType
-exchange_mapi_account_listener_get_type (void)
-{
-	static GType exchange_mapi_account_listener_type = 0;
-
-	if (!exchange_mapi_account_listener_type) {
-		static GTypeInfo info = {
-			sizeof (ExchangeMAPIAccountListenerClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) exchange_mapi_account_listener_class_init,
-			NULL, NULL,
-			sizeof (ExchangeMAPIAccountListener),
-			0,
-			(GInstanceInitFunc) exchange_mapi_account_listener_init
-		};
-		exchange_mapi_account_listener_type = g_type_register_static (PARENT_TYPE, "ExchangeMAPIAccountListener", &info, 0);
-	}
-
-	return exchange_mapi_account_listener_type;
-}
-
 ExchangeMAPIAccountListener *
-exchange_mapi_account_listener_new ()
+exchange_mapi_account_listener_new (void)
 {
 	ExchangeMAPIAccountListener *config_listener;
 
